@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.85';
+our $VERSION = '0.86';
 
 use Dist::Zilla 6.0;
 
@@ -42,6 +42,7 @@ use Dist::Zilla::Plugin::MetaConfig;
 use Dist::Zilla::Plugin::MetaJSON;
 use Dist::Zilla::Plugin::MetaProvides::Package;
 use Dist::Zilla::Plugin::MetaResources;
+use Dist::Zilla::Plugin::MinimumPerl;
 use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::PPPort;
@@ -138,10 +139,7 @@ has _has_xs => (
     is      => 'ro',
     isa     => 'Bool',
     lazy    => 1,
-    default => sub {
-        my $rule = Path::Iterator::Rule->new;
-        return scalar $rule->file->name(qr/\.xs$/)->all('.') ? 1 : 0;
-    },
+    builder => '_build_has_xs',
 );
 
 has pod_coverage_class => (
@@ -278,6 +276,7 @@ sub _build_plugins {
         $self->make_tool,
         $self->_gather_dir_plugin,
         $self->_basic_plugins,
+        'MinimumPerl',
         $self->_authority_plugin,
         $self->_auto_prereqs_plugin,
         $self->_copy_files_from_build_plugin,
@@ -403,22 +402,13 @@ sub _build_files_to_copy_from_build {
     push @files,
         $self->make_tool eq 'MakeMaker' ? 'Makefile.PL' : 'Build.PL';
 
-    my $rule = Path::Iterator::Rule->new;
-    my $dist = $self->dist;
-
-    # We need to skip any existing build dirs
-    my $iter = $rule->file->name('ppport.h')->skip(
-        $rule->new->dir->name(qr{^\Q$dist\E-\d+\.\d+}),
-        $rule->new->dir->name('.build')
-    )->iter('.');
-
-    if ( my $ppport = $iter->() ) {
-
-        # If the file is in a subdir we end up with a name like
-        # "./foo/ppport.h" - the initial "./" bit will confuse the gatherdir
-        # exclude rules.
-        $ppport =~ s{^\./}{};
-        push @files, $ppport;
+    if ( $self->_has_xs ) {
+        if ( $self->payload->{'PPPort.filename'} ) {
+            push @files, $self->payload->{'PPPort.filename'};
+        }
+        else {
+            push @files, 'ppport.h';
+        }
     }
 
     return \@files;
@@ -806,6 +796,16 @@ sub _build_allow_dirty {
     ];
 }
 
+sub _build_has_xs {
+    my $self = shift;
+
+    my $rule = Path::Iterator::Rule->new;
+    return $rule->skip_dirs(
+        '.build',
+        $self->dist . '-*',
+    )->file->name(qr/\.xs$/)->iter('.')->() ? 1 : 0;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -824,7 +824,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.85
+version 0.86
 
 =head1 SYNOPSIS
 
